Skip to main content

fs2f

Description

The fs2f script is for taking snapshots of a file structure into a single file, similar to archiving without compression.

Features

  • Create a snapshot file from a specified directory.
  • Restore the file structure from a snapshot file to a chosen directory.
  • Preserve information about the owner and access rights on UNIX-like systems.
  • List the files and directories stored in the snapshot file.
  • Verify file integrity using hash checks.
  • Strict mode aborts recovery in the event of a hash error.

Installation

  • from GitHub

    git clone https://github.com/codyverse/fs2f.git
    cd fs2f
    
  • via PIP

    pip install fs2f
    

Usage

Options:

  -h, --help        Show this help message and exit.
  -m                Create a file structure snapshot and save it to a file.
  -u                Restore a file structure snapshot from a file.
  -s                Disable strict mode (continue restoring despite file hash mismatches).
  -l snapshot_file  List files and directories stored in a file structure snapshot.
  -d directory      Path to the directory.
  -f snapshot_file  Path to the snapshot file.

Examples

  • Snapshot the entire file structure inside the ./folder/a directory to the file.fs file:

    python3 fs2f.py -m -d ./folder/a -f file.fs
    
  • Restore the file structure from the file.fs file to the ./folder/b directory:

    python3 fs2f.py -u -d ./folder/b -f file.fs
    
  • Display all files and directories saved within the file.fs file:

    python3 fs2f.py -l file.fs
    

Contributing

Feel free to contribute by submitting issues or pull requests!

Metadata

Release files for fs2f 0.0.1.241223

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for fs2f 0.0.1.241223
File Size Uploaded
fs2f-0.0.1.241223.tar.gz 6.6 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for fs2f 0.0.1.241223
File Interpreter ABI Platform
fs2f-0.0.1.241223-py3-none-any.whl Python 3 none any Details

Total release size: 12.0 kB

Release files / fs2f-0.0.1.241223.tar.gz

Download URL fs2f-0.0.1.241223.tar.gz
Size 6.6 kB
Tags Source
SHA-256 checksum
How to use checksums
85e1935261d851bafd3360b161486c7e5b3040a6e9d62bd906c67365905b0125
BLAKE2b-256 checksum
How to use checksums
429626d75ee4e148ae7d06331cc07ea9de6ed8a8128b88dae7d59aaa7bd95d9b
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via python-requests/2.32.3

Release files / fs2f-0.0.1.241223-py3-none-any.whl

Download URL fs2f-0.0.1.241223-py3-none-any.whl
Size 5.5 kB
Tags Python 3
SHA-256 checksum
How to use checksums
882bd5889cf34c7376fc0774ff5b61bb4a30e67ad6a3ea69e12bbaacbe69404e
BLAKE2b-256 checksum
How to use checksums
ee3807fbe696ba4d5b9106b40528c7355cab8fd6b0da6211fea57850ec3a4557
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via python-requests/2.32.3

Release history Release notifications | RSS feed

This release

0.0.1.241223 This release

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page